Crate JESKOserver

Crate JESKOserver 

Structs

Client
Client struct
Server
Server struct

Traits

Decode
Decode trait (wraps serde::Deserialize + bincode)
DeserializeOwned
A data structure that can be deserialized without borrowing any data from the deserializer.
Encode
Encode trait (wraps serde::Serialize + bincode)
Serialize
A data structure that can be serialized into any data format supported by Serde.

Derive Macros

Decode
Encode
Serialize